# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`vios_backup`](#vios_backup): Configures remote backups of VIOS servers to the specified local disk repository.
* [`vios_backup::config`](#vios_backupconfig): Creates a cron entry scheduling the VIOS backups.
* [`vios_backup::install`](#vios_backupinstall): Creates the backup directory structure and installs the script.
* [`vios_backup::params`](#vios_backupparams): Declare constants used within this module.

## Classes

### vios_backup

Performs config backups of a list of VIOS servers via passwordless SSH. This
is accomplished using the viosbr command on each machine.

#### Examples

##### Daily backup of two VIOS with 14 days retention

```puppet
class { 'vios_backup':
  user           => 'backup',
  group          => 'backup',
  base_directory => '/srv/backup/vios',
  days_retention => 14,
  target_vios    => [ 'vio0.example.com', 'vio1.example.com' ],
  cron_job       => {
    hour         => '0',
    minute       => '30',
  },
}
```

#### Parameters

The following parameters are available in the `vios_backup` class.

##### `user`

Data type: `String`

Name of the local user who will own the backup files and run the scheduled
cron job.

Default value: `undef`

##### `group`

Data type: `String`

Name of the local group which will be set on the backup directories.

Default value: `undef`

##### `base_directory`

Data type: `Stdlib::Absolutepath`

The root directory in which each vios backup will be stored. Note that this
must be an absolute path!

Default value: `undef`

##### `days_retention`

Data type: `Integer`

Number of days to retain backups both on each VIOS and on the backup server.
Any backups older than this will be automatically deleted when the job
executes.

Default value: `undef`

##### `target_vios`

Data type: `Array[Stdlib::Fqdn]`

Array of DNS names of VIOS which should be backed up. Currently all VIOS are
processed on the same schedule. Each entry specified here will generate a
subdirectory in `$base_directory` containing the backup files.

Default value: `undef`

##### `cron_job`

Data type: `Hash[String, Variant[String, Integer, Array]]`

Specification of a cron resource that excludes the command and user. The
backup will be scheduled at the frequency specified in this structure.

Default value: `undef`

### vios_backup::config

Schedules the backup job as specified in the main class

### vios_backup::install

Performs preliminary setup needed for the operation of the backups on a given
host. Note that the existence of the backup user and group is assumed.

### vios_backup::params

Declares constants used within this module.

#### Parameters

The following parameters are available in the `vios_backup::params` class.

##### `local_bin`

Data type: `Stdlib::Absolutepath`

Path to the local binary directory on this host. For most operating
systems the value is `/usr/local/bin`

Default value: `undef`

